﻿using System.Drawing;
using System.Drawing.Drawing2D;
using System.Windows.Forms;
using Greatis.PrintSuite;
using Greatis.PrintSuite.Providers;

namespace WindowsFormsApplication1
{
  public partial class MainForm : Form
  {
    public MainForm()
    {
      InitializeComponent();
      Font = SystemFonts.MessageBoxFont;
    }

    private void linkLabel_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
    {
      System.Diagnostics.Process.Start((sender as LinkLabel).Text);
    }

    private void printProvider_PrintContent(object sender, Greatis.PrintSuite.PrintContentEventArgs e)
    {
      // draw orange rectangle on each page
      using (Pen p = new Pen(Brushes.Orange, 10))
        e.Graphics.DrawRectangle(p, e.ContentBounds);
      // reduce the content bound by 0.5 inch from each edge
      Rectangle r = e.ContentBounds;
      r.Inflate(-50, -50);
      e.ContentBounds = new Rectangle(r.Location, r.Size);
      // please, note that we use this provider in the "Page" list 
      // of the document section, so we have it on each section's page
    }

    private void contentProvider_PrintContent(object sender, Greatis.PrintSuite.PrintContentEventArgs e)
    {
      // fill the content bounds
      e.Graphics.FillRectangle(Brushes.LightGray, e.ContentBounds);
      string s = string.Format(
        "DocumentSection {0}\n" +
        "DocumentPage {1}\n" +
        "DocumentProvider {2}\n" +
        "DocumentContent {3}\n" +
        "SectionPage {4}\n" +
        "SectionProvider {5}\n" +
        "SectionContent {6}\n" +
        "PageProvider {7}\n" +
        "PageContent {8}\n" +
        "ProviderPage {9}\n" +
        "ProviderContent {10}",
        e.DocumentSection,
        e.DocumentPage,
        e.DocumentProvider,
        e.DocumentContent,
        e.SectionPage,
        e.SectionProvider,
        e.SectionContent,
        e.PageProvider,
        e.PageContent,
        e.ProviderPage,
        e.ProviderContent);
      using (Font f = new Font("Courier New", 16, FontStyle.Bold))
      {
        e.Graphics.DrawString(s, f, Brushes.Navy, e.ContentBounds.Location);
      }
      // wee need 4 pages for this provider, for example;
      // by default e.ContinuePrint is ContinuePrint.Finish
      if (e.ProviderPage < 3) e.ContinuePrint = ContinuePrint.NextPage;
    }

    private void printProvider2_PrintContent(object sender, PrintContentEventArgs e)
    {
      GraphicsPath p = Service.CreateRoundRectPath(e.ContentBounds, 50);
      e.Graphics.FillPath(Brushes.LightYellow, p);
      Rectangle r = e.ContentBounds;
      r.Inflate(-50, -50);
      e.ContentBounds = new Rectangle(r.Location, r.Size);
    }

		private void tabControl_Selected(object sender, TabControlEventArgs e)
		{
			if (e.TabPage == tabPagePrint) printPreviewControl.InvalidatePreview();
		}

		private void MainForm_Load(object sender, System.EventArgs e)
		{
			printPreviewControl.AutoZoom = true;
		}
  }
}
