﻿using System.Drawing;
using System.Windows.Forms;
using Greatis.PrintSuite;
using Greatis.PrintSuite.Providers;

namespace WindowsFormsApplication1
{
  public partial class MainForm : Form
  {
    public MainForm()
    {
      InitializeComponent();
      Font = SystemFonts.MessageBoxFont;
    }

    private void linkLabel_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
    {
      System.Diagnostics.Process.Start((sender as LinkLabel).Text);
    }

    private void MainForm_Load(object sender, System.EventArgs e)
    {
      printPreviewControl.AutoZoom = true;
      printPreviewControl.Columns = 2;
    }

    private void contentProvider_PrintContent(object sender, Greatis.PrintSuite.PrintContentEventArgs e)
    {
      // just 2 empty pages...
      if (e.ProviderPage < 1) e.ContinuePrint = ContinuePrint.NextPage;
      else e.ContinuePrint = ContinuePrint.Finish;
      // and just draw rectangle to see the content bounds, reduced by PageIndentProvider
      using (Pen p = new Pen(Color.Gray, 10)) e.Graphics.DrawRectangle(p, e.ContentBounds);
    }

    private void pageIndentProvider_PrintContent(object sender, PrintContentEventArgs e)
    {
      PageIndentProvider p = sender as PageIndentProvider;
      if (p != null)
      {
        // call the inherited method to implement default behaviour (indent)
        p.OnPrintContent(e);
        // then draw all we need and... surprise!
        // we can draw not only on the content area with changed Clip property
        // let's draw the circles for selfbinder
        float s = Service.ConvertSize(e, 1f / 3, GraphicsUnit.Inch);
        if (p.IsPageOdd(e))
        {
          e.Graphics.DrawEllipse(
            Pens.Black,
            e.PageBounds.Left + Service.ConvertSize(e, 1f / 6, GraphicsUnit.Inch),
            e.PageBounds.Top + Service.ConvertSize(e, 3, GraphicsUnit.Inch),
            s,
            s);
          e.Graphics.DrawEllipse(
            Pens.Black,
            e.PageBounds.Left + Service.ConvertSize(e, 1f / 6, GraphicsUnit.Inch),
            e.PageBounds.Bottom - Service.ConvertSize(e, 3, GraphicsUnit.Inch),
            s,
            s);
        }
        else
        {
          e.Graphics.DrawEllipse(
            Pens.Black,
            e.PageBounds.Right - Service.ConvertSize(e, 1f / 6, GraphicsUnit.Inch) - s,
            e.PageBounds.Top + Service.ConvertSize(e, 3, GraphicsUnit.Inch),
            s,
            s);
          e.Graphics.DrawEllipse(
            Pens.Black,
            e.PageBounds.Right - Service.ConvertSize(e, 1f / 6, GraphicsUnit.Inch) - s,
            e.PageBounds.Bottom - Service.ConvertSize(e, 3, GraphicsUnit.Inch),
            s,
            s);
        }
      }
    }
  }
}
