﻿using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Windows.Forms;
using Greatis.PrintSuite;

namespace WindowsFormsApplication1
{
  public partial class MainForm : Form
  {
    public MainForm()
    {
      InitializeComponent();
      Font = SystemFonts.MessageBoxFont;
    }

    private void linkLabel_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
    {
      System.Diagnostics.Process.Start((sender as LinkLabel).Text);
    }

    private void AddLog(object sender, string s)
    {
      string p = string.Empty;
      if (sender == contentProvider1) p = "contentProvider1";
      else
        if (sender == contentProvider2) p = "contentProvider2";
        else
          if (sender == printProvider1) p = "printProvider1";
          else p = "printProvider2";
      textBoxLog.Text += s + "(" + p + ")" + Environment.NewLine;
    }

    private void contentProvider_BeginPrintDocument(object sender, Greatis.PrintSuite.PrintNotificationEventArgs e)
    {
      AddLog(sender, "BeginPrintDocument");
    }

    private void contentProvider_BeginPrintPage(object sender, Greatis.PrintSuite.PrintNotificationEventArgs e)
    {
      AddLog(sender, " BeginPrintPage");
    }

    private void contentProvider_BeginPrintProvider(object sender, Greatis.PrintSuite.PrintNotificationEventArgs e)
    {
      AddLog(sender, "  BeginPrintProvider");
    }

    private void contentProvider_BeginPrintContent(object sender, Greatis.PrintSuite.PrintNotificationEventArgs e)
    {
      AddLog(sender, "   BeginPrintContent");
    }

    private void contentProvider_PrintContent(object sender, Greatis.PrintSuite.PrintContentEventArgs e)
    {
      AddLog(sender, "    PrintContent");

      Rectangle r = new Rectangle(e.MarginBounds.Left, e.ContentBounds.Top, e.MarginBounds.Width, e.MarginBounds.Height / 2);
      e.ContentBounds = new Rectangle(r.Left, r.Top + r.Height, r.Width, e.ContentBounds.Height - r.Height);
      r.Inflate(0, -10);
      using (GraphicsPath p = Service.CreateRoundRectPath(r, 40)) e.Graphics.FillPath(Brushes.Orange, p);
      StringFormat sf = new StringFormat();
      sf.Alignment = StringAlignment.Center;
      sf.LineAlignment = StringAlignment.Center;
      using (Font f = new Font("Trebuchet MS", 24))
        e.Graphics.DrawString(string.Format("{0}.{1}", e.SectionProvider, e.ProviderContent), f, Brushes.Black, r, sf);

      if (e.ProviderPage == 1) e.ContinuePrint = ContinuePrint.Finish;
      else
        if (e.PageContent == 0) e.ContinuePrint = ContinuePrint.ThisPage;
        else e.ContinuePrint = ContinuePrint.NextPage;
    }

    private void contentProvider_EndPrintContent(object sender, Greatis.PrintSuite.PrintNotificationEventArgs e)
    {
      AddLog(sender, "   EndPrintContent");
    }

    private void contentProvider_EndPrintProvider(object sender, Greatis.PrintSuite.PrintNotificationEventArgs e)
    {
      AddLog(sender, "  EndPrintProvider");
    }

    private void contentProvider_EndPrintPage(object sender, Greatis.PrintSuite.PrintNotificationEventArgs e)
    {
      AddLog(sender, " EndPrintPage");
    }

    private void contentProvider_EndPrintDocument(object sender, Greatis.PrintSuite.PrintNotificationEventArgs e)
    {
      AddLog(sender, "EndPrintDocument");
    }

    private void contentProvider_QueryPageSettings(object sender, Greatis.PrintSuite.QueryContentPageSettingsEventArgs e)
    {
      AddLog(sender, " QueryPageSettings");
    }

    private void printProvider_PrintContent(object sender, PrintContentEventArgs e)
    {
      AddLog(sender, "    PrintContent");
    }

    private void MainForm_Load(object sender, EventArgs e)
    {
      printPreviewControl.AutoZoom = true;
    }

    private void documentDesigner_BeginPrint(object sender, System.Drawing.Printing.PrintEventArgs e)
    {
      textBoxLog.Text = string.Empty;
    }

  }
}
